# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing
from typing import Union

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_container, div_custom, div_gallery, div_gif_image, div_grid, div_image,
    div_indicator, div_input, div_pager, div_select, div_separator, div_slider,
    div_state, div_switch, div_tabs, div_text, div_video,
)


Div = Union[
    div_image.DivImage,
    div_gif_image.DivGifImage,
    div_text.DivText,
    div_separator.DivSeparator,
    div_container.DivContainer,
    div_grid.DivGrid,
    div_gallery.DivGallery,
    div_pager.DivPager,
    div_tabs.DivTabs,
    div_state.DivState,
    div_custom.DivCustom,
    div_indicator.DivIndicator,
    div_slider.DivSlider,
    div_switch.DivSwitch,
    div_input.DivInput,
    div_select.DivSelect,
    div_video.DivVideo,
]



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_animation_interpolator, div_count


# Element animation parameters.
class DivAnimation(BaseDiv):

    def __init__(
        self, *,
        duration: typing.Optional[typing.Union[Expr, int]] = None,
        end_value: typing.Optional[typing.Union[Expr, float]] = None,
        interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = None,
        items: typing.Optional[typing.Sequence[DivAnimation]] = None,
        name: typing.Optional[typing.Union[Expr, DivAnimationName]] = None,
        repeat: typing.Optional[div_count.DivCount] = None,
        start_delay: typing.Optional[typing.Union[Expr, int]] = None,
        start_value: typing.Optional[typing.Union[Expr, float]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            duration=duration,
            end_value=end_value,
            interpolator=interpolator,
            items=items,
            name=name,
            repeat=repeat,
            start_delay=start_delay,
            start_value=start_value,
            **kwargs,
        )

    duration: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Animation duration in milliseconds.",
    )
    end_value: typing.Optional[typing.Union[Expr, float]] = Field(
        description="Final value of an animation.",
    )
    interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = Field(
        description=(
            "Animation speed nature. When the value is set to `spring` — "
            "animation of dampingfluctuations cut to 0.7 with the "
            "`damping=1` parameter. Other options correspondto the "
            "Bezier curve:`linear` — cubic-bezier(0, 0, 1, 1);`ease` "
            "—cubic-bezier(0.25, 0.1, 0.25, 1);`ease_in` — "
            "cubic-bezier(0.42, 0, 1,1);`ease_out` — cubic-bezier(0, 0, "
            "0.58, 1);`ease_in_out` — cubic-bezier(0.42, 0,0.58, 1)."
        ),
    )
    items: typing.Optional[typing.Sequence[DivAnimation]] = Field(
        description="Animation elements.",
    )
    name: typing.Union[Expr, DivAnimationName] = Field(
        description="Animation type.",
    )
    repeat: typing.Optional[div_count.DivCount] = Field(
        description="Number of animation repetitions.",
    )
    start_delay: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Delay in milliseconds before animation starts.",
    )
    start_value: typing.Optional[typing.Union[Expr, float]] = Field(
        description="Starting value of an animation.",
    )


class DivAnimationName(str, enum.Enum):
    FADE = "fade"
    TRANSLATE = "translate"
    SCALE = "scale"
    NATIVE = "native"
    SET = "set"
    NO_ANIMATION = "no_animation"


DivAnimation.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import (
    div_accessibility, div_action, div_alignment_horizontal,
    div_alignment_vertical, div_animation, div_animator,
    div_appearance_transition, div_background, div_blend_mode, div_border,
    div_change_transition, div_disappear_action, div_edge_insets, div_extension,
    div_fixed_size, div_focus, div_font_weight, div_function,
    div_layout_provider, div_line_style, div_shadow, div_size, div_size_unit,
    div_text_alignment_vertical, div_text_gradient, div_text_range_background,
    div_text_range_border, div_text_range_mask, div_tooltip, div_transform,
    div_transition_trigger, div_trigger, div_variable, div_visibility,
    div_visibility_action,
)


# Text.
class DivText(BaseDiv):

    def __init__(
        self, *,
        type: str = "text",
        accessibility: typing.Optional[div_accessibility.DivAccessibility] = None,
        action: typing.Optional[div_action.DivAction] = None,
        action_animation: typing.Optional[div_animation.DivAnimation] = None,
        actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = None,
        alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = None,
        alpha: typing.Optional[typing.Union[Expr, float]] = None,
        animators: typing.Optional[typing.Sequence[div_animator.DivAnimator]] = None,
        auto_ellipsize: typing.Optional[typing.Union[Expr, bool]] = None,
        background: typing.Optional[typing.Sequence[div_background.DivBackground]] = None,
        border: typing.Optional[div_border.DivBorder] = None,
        column_span: typing.Optional[typing.Union[Expr, int]] = None,
        disappear_actions: typing.Optional[typing.Sequence[div_disappear_action.DivDisappearAction]] = None,
        doubletap_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        ellipsis: typing.Optional[DivTextEllipsis] = None,
        extensions: typing.Optional[typing.Sequence[div_extension.DivExtension]] = None,
        focus: typing.Optional[div_focus.DivFocus] = None,
        focused_text_color: typing.Optional[typing.Union[Expr, str]] = None,
        font_family: typing.Optional[typing.Union[Expr, str]] = None,
        font_feature_settings: typing.Optional[typing.Union[Expr, str]] = None,
        font_size: typing.Optional[typing.Union[Expr, int]] = None,
        font_size_unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = None,
        font_weight: typing.Optional[typing.Union[Expr, div_font_weight.DivFontWeight]] = None,
        font_weight_value: typing.Optional[typing.Union[Expr, int]] = None,
        functions: typing.Optional[typing.Sequence[div_function.DivFunction]] = None,
        height: typing.Optional[div_size.DivSize] = None,
        hover_end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        hover_start_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        images: typing.Optional[typing.Sequence[DivTextImage]] = None,
        layout_provider: typing.Optional[div_layout_provider.DivLayoutProvider] = None,
        letter_spacing: typing.Optional[typing.Union[Expr, float]] = None,
        line_height: typing.Optional[typing.Union[Expr, int]] = None,
        longtap_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        margins: typing.Optional[div_edge_insets.DivEdgeInsets] = None,
        max_lines: typing.Optional[typing.Union[Expr, int]] = None,
        min_hidden_lines: typing.Optional[typing.Union[Expr, int]] = None,
        paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = None,
        press_end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        press_start_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        ranges: typing.Optional[typing.Sequence[DivTextRange]] = None,
        reuse_id: typing.Optional[typing.Union[Expr, str]] = None,
        row_span: typing.Optional[typing.Union[Expr, int]] = None,
        selectable: typing.Optional[typing.Union[Expr, bool]] = None,
        selected_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        strike: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = None,
        text: typing.Optional[typing.Union[Expr, str]] = None,
        text_alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = None,
        text_alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = None,
        text_color: typing.Optional[typing.Union[Expr, str]] = None,
        text_gradient: typing.Optional[div_text_gradient.DivTextGradient] = None,
        text_shadow: typing.Optional[div_shadow.DivShadow] = None,
        tighten_width: typing.Optional[typing.Union[Expr, bool]] = None,
        tooltips: typing.Optional[typing.Sequence[div_tooltip.DivTooltip]] = None,
        transform: typing.Optional[div_transform.DivTransform] = None,
        transition_change: typing.Optional[div_change_transition.DivChangeTransition] = None,
        transition_in: typing.Optional[div_appearance_transition.DivAppearanceTransition] = None,
        transition_out: typing.Optional[div_appearance_transition.DivAppearanceTransition] = None,
        transition_triggers: typing.Optional[typing.Sequence[typing.Union[Expr, div_transition_trigger.DivTransitionTrigger]]] = None,
        truncate: typing.Optional[typing.Union[Expr, DivTextTruncate]] = None,
        underline: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = None,
        variable_triggers: typing.Optional[typing.Sequence[div_trigger.DivTrigger]] = None,
        variables: typing.Optional[typing.Sequence[div_variable.DivVariable]] = None,
        visibility: typing.Optional[typing.Union[Expr, div_visibility.DivVisibility]] = None,
        visibility_action: typing.Optional[div_visibility_action.DivVisibilityAction] = None,
        visibility_actions: typing.Optional[typing.Sequence[div_visibility_action.DivVisibilityAction]] = None,
        width: typing.Optional[div_size.DivSize] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            accessibility=accessibility,
            action=action,
            action_animation=action_animation,
            actions=actions,
            alignment_horizontal=alignment_horizontal,
            alignment_vertical=alignment_vertical,
            alpha=alpha,
            animators=animators,
            auto_ellipsize=auto_ellipsize,
            background=background,
            border=border,
            column_span=column_span,
            disappear_actions=disappear_actions,
            doubletap_actions=doubletap_actions,
            ellipsis=ellipsis,
            extensions=extensions,
            focus=focus,
            focused_text_color=focused_text_color,
            font_family=font_family,
            font_feature_settings=font_feature_settings,
            font_size=font_size,
            font_size_unit=font_size_unit,
            font_weight=font_weight,
            font_weight_value=font_weight_value,
            functions=functions,
            height=height,
            hover_end_actions=hover_end_actions,
            hover_start_actions=hover_start_actions,
            id=id,
            images=images,
            layout_provider=layout_provider,
            letter_spacing=letter_spacing,
            line_height=line_height,
            longtap_actions=longtap_actions,
            margins=margins,
            max_lines=max_lines,
            min_hidden_lines=min_hidden_lines,
            paddings=paddings,
            press_end_actions=press_end_actions,
            press_start_actions=press_start_actions,
            ranges=ranges,
            reuse_id=reuse_id,
            row_span=row_span,
            selectable=selectable,
            selected_actions=selected_actions,
            strike=strike,
            text=text,
            text_alignment_horizontal=text_alignment_horizontal,
            text_alignment_vertical=text_alignment_vertical,
            text_color=text_color,
            text_gradient=text_gradient,
            text_shadow=text_shadow,
            tighten_width=tighten_width,
            tooltips=tooltips,
            transform=transform,
            transition_change=transition_change,
            transition_in=transition_in,
            transition_out=transition_out,
            transition_triggers=transition_triggers,
            truncate=truncate,
            underline=underline,
            variable_triggers=variable_triggers,
            variables=variables,
            visibility=visibility,
            visibility_action=visibility_action,
            visibility_actions=visibility_actions,
            width=width,
            **kwargs,
        )

    type: str = Field(default="text")
    accessibility: typing.Optional[div_accessibility.DivAccessibility] = Field(
        description="Accessibility settings.",
    )
    action: typing.Optional[div_action.DivAction] = Field(
        description=(
            "One action when clicking on an element. Not used if the "
            "`actions` parameter isset."
        ),
    )
    action_animation: typing.Optional[div_animation.DivAnimation] = Field(
        description=(
            "Click animation. The web only supports the following "
            "values: `fade`, `scale`,`native`, `no_animation` and `set`."
        ),
    )
    actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Multiple actions when clicking on an element.",
    )
    alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = Field(
        description=(
            "Horizontal alignment of an element inside the parent "
            "element."
        ),
    )
    alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = Field(
        description=(
            "Vertical alignment of an element inside the parent element."
        ),
    )
    alpha: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Sets transparency of the entire element: `0` — completely "
            "transparent, `1` —opaque."
        ),
    )
    animators: typing.Optional[typing.Sequence[div_animator.DivAnimator]] = Field(
        description=(
            "Declaration of animators that change variable values over "
            "time."
        ),
    )
    auto_ellipsize: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Automatic text cropping to fit the container size.",
    )
    background: typing.Optional[typing.Sequence[div_background.DivBackground]] = Field(
        description="Element background. It can contain multiple layers.",
    )
    border: typing.Optional[div_border.DivBorder] = Field(
        description="Element stroke.",
    )
    column_span: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Merges cells in a column of the [grid](div-grid.md) "
            "element."
        ),
    )
    disappear_actions: typing.Optional[typing.Sequence[div_disappear_action.DivDisappearAction]] = Field(
        description="Actions when an element disappears from the screen.",
    )
    doubletap_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Action when double-clicking on an element.",
    )
    ellipsis: typing.Optional[DivTextEllipsis] = Field(
        description=(
            "Text cropping marker. It is displayed when text size "
            "exceeds the limit on thenumber of lines."
        ),
    )
    extensions: typing.Optional[typing.Sequence[div_extension.DivExtension]] = Field(
        description=(
            "Extensions for additional processing of an element. The "
            "list of extensions isgiven in "
            "[DivExtension](../../extensions)."
        ),
    )
    focus: typing.Optional[div_focus.DivFocus] = Field(
        description="Parameters when focusing on an element or losing focus.",
    )
    focused_text_color: typing.Optional[typing.Union[Expr, str]] = Field(
        format="color", 
        description="Text color when focusing on the element.",
    )
    font_family: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Font family:`text` — a standard text font;`display` — a "
            "family of fonts with alarge font size."
        ),
    )
    font_feature_settings: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "List of OpenType font features. The format matches the CSS "
            "attribute\"font-feature-settings\". Learn "
            "more:https://www.w3.org/TR/css-fonts-3/#font-feature-settin"
            "gs-prop"
        ),
    )
    font_size: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Font size.",
    )
    font_size_unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = Field(
    )
    font_weight: typing.Optional[typing.Union[Expr, div_font_weight.DivFontWeight]] = Field(
        description="Style.",
    )
    font_weight_value: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Style. Numeric value.",
    )
    functions: typing.Optional[typing.Sequence[div_function.DivFunction]] = Field(
        description="User functions.",
    )
    height: typing.Optional[div_size.DivSize] = Field(
        description=(
            "Element height. For Android: if there is text in this or in "
            "a child element,specify height in `sp` to scale the element "
            "together with the text. To learn moreabout units of size "
            "measurement, see [Layout inside the card](../../layout)."
        ),
    )
    hover_end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions performed after hovering over an element. Available "
            "on platforms thatsupport pointing devices (such as a mouse "
            "or stylus)."
        ),
    )
    hover_start_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions performed when hovering over an element. Available "
            "on platforms thatsupport pointing devices (such as a mouse "
            "or stylus)."
        ),
    )
    id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Element ID. It must be unique within the root element. It "
            "is used as`accessibilityIdentifier` on iOS."
        ),
    )
    images: typing.Optional[typing.Sequence[DivTextImage]] = Field(
        description="Images embedded in text.",
    )
    layout_provider: typing.Optional[div_layout_provider.DivLayoutProvider] = Field(
        description="Provides data on the actual size of the element.",
    )
    letter_spacing: typing.Optional[typing.Union[Expr, float]] = Field(
        description="Spacing between characters.",
    )
    line_height: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Line spacing of the text.",
    )
    longtap_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Action when long-clicking an element. Doesn\'t work on "
            "devices that don\'t supporttouch gestures."
        ),
    )
    margins: typing.Optional[div_edge_insets.DivEdgeInsets] = Field(
        description="External margins from the element stroke.",
    )
    max_lines: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Maximum number of lines not to be cropped when breaking the "
            "limits."
        ),
    )
    min_hidden_lines: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Minimum number of cropped lines when breaking the limits.",
    )
    paddings: typing.Optional[div_edge_insets.DivEdgeInsets] = Field(
        description="Internal margins from the element stroke.",
    )
    press_end_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions performed after clicking/tapping an element.",
    )
    press_start_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions performed at the start of a click/tap on an "
            "element."
        ),
    )
    ranges: typing.Optional[typing.Sequence[DivTextRange]] = Field(
        description=(
            "A character range in which additional style parameters can "
            "be set. Defined bymandatory `start` and `end` fields."
        ),
    )
    reuse_id: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "ID for the div object structure. Used to optimize block "
            "reuse. See [blockreuse](../../reuse/reuse.md)."
        ),
    )
    row_span: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Merges cells in a string of the [grid](div-grid.md) "
            "element."
        ),
    )
    selectable: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Ability to select and copy text.",
    )
    selected_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "List of [actions](div-action.md) to be executed when "
            "selecting an element in[pager](div-pager.md)."
        ),
    )
    strike: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = Field(
        description="Strikethrough.",
    )
    text: typing.Union[Expr, str] = Field(
        description="Text.",
    )
    text_alignment_horizontal: typing.Optional[typing.Union[Expr, div_alignment_horizontal.DivAlignmentHorizontal]] = Field(
        description="Horizontal text alignment.",
    )
    text_alignment_vertical: typing.Optional[typing.Union[Expr, div_alignment_vertical.DivAlignmentVertical]] = Field(
        description="Vertical text alignment.",
    )
    text_color: typing.Optional[typing.Union[Expr, str]] = Field(
        format="color", 
        description=(
            "Text color. Not used if the `text_gradient` parameter is "
            "set."
        ),
    )
    text_gradient: typing.Optional[div_text_gradient.DivTextGradient] = Field(
        description="Gradient text color.",
    )
    text_shadow: typing.Optional[div_shadow.DivShadow] = Field(
        description="Parameters of the shadow applied to the text.",
    )
    tighten_width: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Limit the text width to the maximum line width. Applies "
            "only when the width isset to `wrap_content`, "
            "`constrained=true`, and `max_size` is specified."
        ),
    )
    tooltips: typing.Optional[typing.Sequence[div_tooltip.DivTooltip]] = Field(
        description=(
            "Tooltips linked to an element. A tooltip can be shown "
            "by`div-action://show_tooltip?id=`, hidden by "
            "`div-action://hide_tooltip?id=` where`id` — tooltip id."
        ),
    )
    transform: typing.Optional[div_transform.DivTransform] = Field(
        description=(
            "Applies the passed transformation to the element. Content "
            "that doesn\'t fit intothe original view area is cut off."
        ),
    )
    transition_change: typing.Optional[div_change_transition.DivChangeTransition] = Field(
        description=(
            "Change animation. It is played when the position or size of "
            "an element changes inthe new layout."
        ),
    )
    transition_in: typing.Optional[div_appearance_transition.DivAppearanceTransition] = Field(
        description=(
            "Appearance animation. It is played when an element with a "
            "new ID appears. Tolearn more about the concept of "
            "transitions, see "
            "[Animatedtransitions](../../interaction#animation/transitio"
            "n-animation)."
        ),
    )
    transition_out: typing.Optional[div_appearance_transition.DivAppearanceTransition] = Field(
        description=(
            "Disappearance animation. It is played when an element "
            "disappears in the newlayout."
        ),
    )
    transition_triggers: typing.Optional[typing.Sequence[typing.Union[Expr, div_transition_trigger.DivTransitionTrigger]]] = Field(
        min_items=1, 
        description=(
            "Animation starting triggers. Default value: `[state_change, "
            "visibility_change]`."
        ),
    )
    truncate: typing.Optional[typing.Union[Expr, DivTextTruncate]] = Field(
        description="Text cropping method. Use `ellipsis` instead. @deprecated",
    )
    underline: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = Field(
        description="Underline.",
    )
    variable_triggers: typing.Optional[typing.Sequence[div_trigger.DivTrigger]] = Field(
        description="Triggers for changing variables within an element.",
    )
    variables: typing.Optional[typing.Sequence[div_variable.DivVariable]] = Field(
        description=(
            "Declaration of variables that can be used within an "
            "element. Variables declaredin this array can only be used "
            "within the element and its child elements."
        ),
    )
    visibility: typing.Optional[typing.Union[Expr, div_visibility.DivVisibility]] = Field(
        description="Element visibility.",
    )
    visibility_action: typing.Optional[div_visibility_action.DivVisibilityAction] = Field(
        description=(
            "Tracking visibility of a single element. Not used if the "
            "`visibility_actions`parameter is set."
        ),
    )
    visibility_actions: typing.Optional[typing.Sequence[div_visibility_action.DivVisibilityAction]] = Field(
        description="Actions when an element appears on the screen.",
    )
    width: typing.Optional[div_size.DivSize] = Field(
        description="Element width.",
    )


class DivTextTruncate(str, enum.Enum):
    NONE = "none"
    START = "start"
    END = "end"
    MIDDLE = "middle"


# Text cropping marker. It is displayed when text size exceeds the limit on the
# number of lines.
class DivTextEllipsis(BaseDiv):

    def __init__(
        self, *,
        actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        images: typing.Optional[typing.Sequence[DivTextImage]] = None,
        ranges: typing.Optional[typing.Sequence[DivTextRange]] = None,
        text: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            actions=actions,
            images=images,
            ranges=ranges,
            text=text,
            **kwargs,
        )

    actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions when clicking on a crop marker.",
    )
    images: typing.Optional[typing.Sequence[DivTextImage]] = Field(
        description="Images embedded in a crop marker.",
    )
    ranges: typing.Optional[typing.Sequence[DivTextRange]] = Field(
        description=(
            "Character ranges inside a crop marker with different text "
            "styles."
        ),
    )
    text: typing.Union[Expr, str] = Field(
        description="Marker text.",
    )


DivTextEllipsis.update_forward_refs()


# Image.
class DivTextImage(BaseDiv):

    def __init__(
        self, *,
        accessibility: typing.Optional[ImageAccessibility] = None,
        alignment_vertical: typing.Optional[typing.Union[Expr, div_text_alignment_vertical.DivTextAlignmentVertical]] = None,
        height: typing.Optional[div_fixed_size.DivFixedSize] = None,
        indexing_direction: typing.Optional[typing.Union[Expr, ImageIndexingDirection]] = None,
        preload_required: typing.Optional[typing.Union[Expr, bool]] = None,
        start: typing.Optional[typing.Union[Expr, int]] = None,
        tint_color: typing.Optional[typing.Union[Expr, str]] = None,
        tint_mode: typing.Optional[typing.Union[Expr, div_blend_mode.DivBlendMode]] = None,
        url: typing.Optional[typing.Union[Expr, str]] = None,
        width: typing.Optional[div_fixed_size.DivFixedSize] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            accessibility=accessibility,
            alignment_vertical=alignment_vertical,
            height=height,
            indexing_direction=indexing_direction,
            preload_required=preload_required,
            start=start,
            tint_color=tint_color,
            tint_mode=tint_mode,
            url=url,
            width=width,
            **kwargs,
        )

    accessibility: typing.Optional[ImageAccessibility] = Field(
    )
    alignment_vertical: typing.Optional[typing.Union[Expr, div_text_alignment_vertical.DivTextAlignmentVertical]] = Field(
        description="Vertical image alignment within the row.",
    )
    height: typing.Optional[div_fixed_size.DivFixedSize] = Field(
        description="Image height.",
    )
    indexing_direction: typing.Optional[typing.Union[Expr, ImageIndexingDirection]] = Field(
        description=(
            "Defines the direction in the `start` parameter:– `normal` "
            "is for regular stringindexing ([0, 1, 2, ..., N]). Use it "
            "if you need to insert an image by indexrelative to the "
            "beginning of a string.– `reversed` is for indexing a string "
            "fromthe end to the beginning ([N, ..., 2, 1, 0]). Use it if "
            "you need to insert animage by index relative to the end of "
            "a string."
        ),
    )
    preload_required: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Background image must be loaded before the display.",
    )
    start: typing.Union[Expr, int] = Field(
        description=(
            "A symbol to insert prior to an image. To insert an image at "
            "the end of the text,specify the number of the last "
            "character plus one."
        ),
    )
    tint_color: typing.Optional[typing.Union[Expr, str]] = Field(
        format="color", 
        description="New color of a contour image.",
    )
    tint_mode: typing.Optional[typing.Union[Expr, div_blend_mode.DivBlendMode]] = Field(
        description="Blend mode of the color specified in `tint_color`.",
    )
    url: typing.Union[Expr, str] = Field(
        format="uri", 
        description="Image URL.",
    )
    width: typing.Optional[div_fixed_size.DivFixedSize] = Field(
        description="Image width.",
    )


class ImageIndexingDirection(str, enum.Enum):
    NORMAL = "normal"
    REVERSED = "reversed"


class ImageAccessibility(BaseDiv):

    def __init__(
        self, *,
        description: typing.Optional[typing.Union[Expr, str]] = None,
        type: typing.Optional[typing.Union[Expr, AccessibilityType]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            description=description,
            type=type,
            **kwargs,
        )

    description: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Element description. It is used as the main description for "
            "screen readingapplications."
        ),
    )
    type: typing.Optional[typing.Union[Expr, AccessibilityType]] = Field(
        description=(
            "Element role. Used to correctly identify an element by the "
            "accessibility service.For example, the `list` element is "
            "used to group list elements into one element."
        ),
    )


class AccessibilityType(str, enum.Enum):
    NONE = "none"
    BUTTON = "button"
    IMAGE = "image"
    TEXT = "text"
    AUTO = "auto"


ImageAccessibility.update_forward_refs()


DivTextImage.update_forward_refs()


# Additional parameters of the character range.
class DivTextRange(BaseDiv):

    def __init__(
        self, *,
        actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        alignment_vertical: typing.Optional[typing.Union[Expr, div_text_alignment_vertical.DivTextAlignmentVertical]] = None,
        background: typing.Optional[div_text_range_background.DivTextRangeBackground] = None,
        baseline_offset: typing.Optional[typing.Union[Expr, float]] = None,
        border: typing.Optional[div_text_range_border.DivTextRangeBorder] = None,
        end: typing.Optional[typing.Union[Expr, int]] = None,
        font_family: typing.Optional[typing.Union[Expr, str]] = None,
        font_feature_settings: typing.Optional[typing.Union[Expr, str]] = None,
        font_size: typing.Optional[typing.Union[Expr, int]] = None,
        font_size_unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = None,
        font_weight: typing.Optional[typing.Union[Expr, div_font_weight.DivFontWeight]] = None,
        font_weight_value: typing.Optional[typing.Union[Expr, int]] = None,
        letter_spacing: typing.Optional[typing.Union[Expr, float]] = None,
        line_height: typing.Optional[typing.Union[Expr, int]] = None,
        mask: typing.Optional[div_text_range_mask.DivTextRangeMask] = None,
        start: typing.Optional[typing.Union[Expr, int]] = None,
        strike: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = None,
        text_color: typing.Optional[typing.Union[Expr, str]] = None,
        text_shadow: typing.Optional[div_shadow.DivShadow] = None,
        top_offset: typing.Optional[typing.Union[Expr, int]] = None,
        underline: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            actions=actions,
            alignment_vertical=alignment_vertical,
            background=background,
            baseline_offset=baseline_offset,
            border=border,
            end=end,
            font_family=font_family,
            font_feature_settings=font_feature_settings,
            font_size=font_size,
            font_size_unit=font_size_unit,
            font_weight=font_weight,
            font_weight_value=font_weight_value,
            letter_spacing=letter_spacing,
            line_height=line_height,
            mask=mask,
            start=start,
            strike=strike,
            text_color=text_color,
            text_shadow=text_shadow,
            top_offset=top_offset,
            underline=underline,
            **kwargs,
        )

    actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Action when clicking on text.",
    )
    alignment_vertical: typing.Optional[typing.Union[Expr, div_text_alignment_vertical.DivTextAlignmentVertical]] = Field(
        description=(
            "Vertical text alignment within the row. Ignored when a "
            "baseline offset isspecified."
        ),
    )
    background: typing.Optional[div_text_range_background.DivTextRangeBackground] = Field(
        description="Character range background.",
    )
    baseline_offset: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Vertical baseline offset in a character range. If set, "
            "vertical alignment isignored."
        ),
    )
    border: typing.Optional[div_text_range_border.DivTextRangeBorder] = Field(
        description="Character range border.",
    )
    end: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Ordinal number of the last character to be included in the "
            "range. If the propertyis omitted, the range ends at the "
            "last character of the text."
        ),
    )
    font_family: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Font family:`text` — a standard text font;`display` — a "
            "family of fonts with alarge font size."
        ),
    )
    font_feature_settings: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "List of OpenType font features. The format matches the CSS "
            "attribute\"font-feature-settings\". Learn "
            "more:https://www.w3.org/TR/css-fonts-3/#font-feature-settin"
            "gs-prop"
        ),
    )
    font_size: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Font size.",
    )
    font_size_unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = Field(
        description=(
            "Unit of measurement:`px` — a physical pixel.`dp` — a "
            "logical pixel that doesn\'tdepend on screen density.`sp` — "
            "a logical pixel that depends on the font size ona device. "
            "Specify height in `sp`. Only available on Android."
        ),
    )
    font_weight: typing.Optional[typing.Union[Expr, div_font_weight.DivFontWeight]] = Field(
        description="Style.",
    )
    font_weight_value: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Style. Numeric value.",
    )
    letter_spacing: typing.Optional[typing.Union[Expr, float]] = Field(
        description="Spacing between characters.",
    )
    line_height: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Line spacing of the text. Units specified in "
            "`font_size_unit`."
        ),
    )
    mask: typing.Optional[div_text_range_mask.DivTextRangeMask] = Field(
        description=(
            "A mask that hides a part of text. To show the hidden text, "
            "disable the mask usingthe `is_enabled` property."
        ),
    )
    start: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Ordinal number of a character which the range begins from. "
            "The first characterhas a number `0`."
        ),
    )
    strike: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = Field(
        description="Strikethrough.",
    )
    text_color: typing.Optional[typing.Union[Expr, str]] = Field(
        format="color", 
        description="Text color.",
    )
    text_shadow: typing.Optional[div_shadow.DivShadow] = Field(
        description="Parameters of the shadow applied to the character range.",
    )
    top_offset: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Top margin of the character range. Units specified in "
            "`font_size_unit`."
        ),
    )
    underline: typing.Optional[typing.Union[Expr, div_line_style.DivLineStyle]] = Field(
        description="Underline.",
    )


DivTextRange.update_forward_refs()


DivText.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_evaluable_type, div_function_argument


# User-defined function.
class DivFunction(BaseDiv):

    def __init__(
        self, *,
        arguments: typing.Optional[typing.Sequence[div_function_argument.DivFunctionArgument]] = None,
        body: typing.Optional[typing.Union[Expr, str]] = None,
        name: typing.Optional[typing.Union[Expr, str]] = None,
        return_type: typing.Optional[typing.Union[Expr, div_evaluable_type.DivEvaluableType]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            arguments=arguments,
            body=body,
            name=name,
            return_type=return_type,
            **kwargs,
        )

    arguments: typing.Sequence[div_function_argument.DivFunctionArgument] = Field(
        description="Function argument.",
    )
    body: typing.Union[Expr, str] = Field(
        description=(
            "Function body. Evaluated as an expression using the passed "
            "arguments. Doesn\'tcapture external variables."
        ),
    )
    name: typing.Union[Expr, str] = Field(
        description="Function name.",
    )
    return_type: typing.Union[Expr, div_evaluable_type.DivEvaluableType] = Field(
        description="Return value type.",
    )


DivFunction.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_action


# Loads additional data in `div-patch` format and updates the current element.
class DivActionDownload(BaseDiv):

    def __init__(
        self, *,
        type: str = "download",
        on_fail_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        on_success_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        url: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            on_fail_actions=on_fail_actions,
            on_success_actions=on_success_actions,
            url=url,
            **kwargs,
        )

    type: str = Field(default="download")
    on_fail_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Actions in case of unsuccessful loading if the host "
            "reported it or the waitingtime expired."
        ),
    )
    on_success_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description="Actions in case of successful loading.",
    )
    url: typing.Union[Expr, str] = Field(
        format="uri", 
        description="Link for receiving changes.",
    )


DivActionDownload.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_animation_interpolator


# Pages are stacked during animation overlapping one another.
class DivPageTransformationOverlap(BaseDiv):

    def __init__(
        self, *,
        type: str = "overlap",
        interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = None,
        next_page_alpha: typing.Optional[typing.Union[Expr, float]] = None,
        next_page_scale: typing.Optional[typing.Union[Expr, float]] = None,
        previous_page_alpha: typing.Optional[typing.Union[Expr, float]] = None,
        previous_page_scale: typing.Optional[typing.Union[Expr, float]] = None,
        reversed_stacking_order: typing.Optional[typing.Union[Expr, bool]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            interpolator=interpolator,
            next_page_alpha=next_page_alpha,
            next_page_scale=next_page_scale,
            previous_page_alpha=previous_page_alpha,
            previous_page_scale=previous_page_scale,
            reversed_stacking_order=reversed_stacking_order,
            **kwargs,
        )

    type: str = Field(default="overlap")
    interpolator: typing.Optional[typing.Union[Expr, div_animation_interpolator.DivAnimationInterpolator]] = Field(
        description=(
            "Animation speed adjustment. When the value is set to "
            "`spring`, it’s a dampedoscillation animation truncated to "
            "0.7, with the `damping=1` parameter. Othervalues correspond "
            "to the Bezier curve:`linear` — cubic-bezier(0, 0, 1, "
            "1)`ease` —cubic-bezier(0.25, 0.1, 0.25, 1)`ease_in` — "
            "cubic-bezier(0.42, 0, 1, 1)`ease_out`— cubic-bezier(0, 0, "
            "0.58, 1)`ease_in_out` — cubic-bezier(0.42, 0, 0.58, 1)"
        ),
    )
    next_page_alpha: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Minimum transparency of the next page, within the range [0, "
            "1], when scrollingthrough the pager. The following page is "
            "always the page with a larger ordinalnumber in the `items` "
            "list, regardless of the scrolling direction."
        ),
    )
    next_page_scale: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Scaling the next page during pager scrolling. The following "
            "page is always thepage with a larger ordinal number in the "
            "`items` list, regardless of thescrolling direction."
        ),
    )
    previous_page_alpha: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Minimum transparency of the previous page, in the range [0, "
            "1], during pagerscrolling. The previous page is always the "
            "page with a lower ordinal number inthe `items` list, "
            "regardless of the scrolling direction."
        ),
    )
    previous_page_scale: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "Scaling the previous page during pager scrolling. The "
            "previous page is always thepage with a lower ordinal number "
            "in the `items` list, regardless of the scrollingdirection."
        ),
    )
    reversed_stacking_order: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "If the value is `false`, the following pages will be "
            "stacked on top of theprevious ones. If the value is `true`, "
            "the reverse happens. The following page isalways the page "
            "with a larger ordinal number in the `items` list, "
            "regardless ofthe scrolling direction."
        ),
    )


DivPageTransformationOverlap.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_typed_value


# Temporarily saves the variable in storage.
class DivActionSetStoredValue(BaseDiv):

    def __init__(
        self, *,
        type: str = "set_stored_value",
        lifetime: typing.Optional[typing.Union[Expr, int]] = None,
        name: typing.Optional[typing.Union[Expr, str]] = None,
        value: typing.Optional[div_typed_value.DivTypedValue] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            lifetime=lifetime,
            name=name,
            value=value,
            **kwargs,
        )

    type: str = Field(default="set_stored_value")
    lifetime: typing.Union[Expr, int] = Field(
        description="Duration of storage in seconds.",
    )
    name: typing.Union[Expr, str] = Field(
        description="Name of the saved variable.",
    )
    value: div_typed_value.DivTypedValue = Field(
        description="Saved value.",
    )


DivActionSetStoredValue.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div, div_action, div_animation, div_point, div_tooltip_mode


# Tooltip.
class DivTooltip(BaseDiv):

    def __init__(
        self, *,
        animation_in: typing.Optional[div_animation.DivAnimation] = None,
        animation_out: typing.Optional[div_animation.DivAnimation] = None,
        background_accessibility_description: typing.Optional[typing.Union[Expr, str]] = None,
        close_by_tap_outside: typing.Optional[typing.Union[Expr, bool]] = None,
        div: typing.Optional[div.Div] = None,
        duration: typing.Optional[typing.Union[Expr, int]] = None,
        id: typing.Optional[typing.Union[Expr, str]] = None,
        mode: typing.Optional[div_tooltip_mode.DivTooltipMode] = None,
        offset: typing.Optional[div_point.DivPoint] = None,
        position: typing.Optional[typing.Union[Expr, DivTooltipPosition]] = None,
        tap_outside_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            animation_in=animation_in,
            animation_out=animation_out,
            background_accessibility_description=background_accessibility_description,
            close_by_tap_outside=close_by_tap_outside,
            div=div,
            duration=duration,
            id=id,
            mode=mode,
            offset=offset,
            position=position,
            tap_outside_actions=tap_outside_actions,
            **kwargs,
        )

    animation_in: typing.Optional[div_animation.DivAnimation] = Field(
        description=(
            "Tooltip appearance animation. By default, the tooltip will "
            "be appearing graduallywith an offset from the anchor point "
            "by 10 dp."
        ),
    )
    animation_out: typing.Optional[div_animation.DivAnimation] = Field(
        description=(
            "Tooltip disappearance animation. By default, the tooltip "
            "will disappear graduallywith an offset from the anchor "
            "point by 10 dp."
        ),
    )
    background_accessibility_description: typing.Optional[typing.Union[Expr, str]] = Field(
        description=(
            "Description for accessibility of the background tap action "
            "for tooltip."
        ),
    )
    close_by_tap_outside: typing.Optional[typing.Union[Expr, bool]] = Field(
        description="Allows dismissing tooltip by tapping outside of it.",
    )
    div: div.Div = Field(
        description=(
            "An element that will be shown in a tooltip. If there are "
            "tooltips inside anelement, they won\'t be shown."
        ),
    )
    duration: typing.Optional[typing.Union[Expr, int]] = Field(
        description=(
            "Duration of the tooltip visibility in milliseconds. When "
            "the value is set to `0`,the tooltip will be visible until "
            "the user hides it."
        ),
    )
    id: typing.Union[Expr, str] = Field(
        description=(
            "Tooltip ID. It is used to avoid re-showing. It must be "
            "unique for all elementtooltips."
        ),
    )
    mode: typing.Optional[div_tooltip_mode.DivTooltipMode] = Field(
        description="Tooltip modes.",
    )
    offset: typing.Optional[div_point.DivPoint] = Field(
        description="Shift relative to an anchor point.",
    )
    position: typing.Union[Expr, DivTooltipPosition] = Field(
        description=(
            "The position of a tooltip relative to an element it belongs "
            "to."
        ),
    )
    tap_outside_actions: typing.Optional[typing.Sequence[div_action.DivAction]] = Field(
        description=(
            "Specifies actions triggered by tapping outside the tooltip."
        ),
    )


class DivTooltipPosition(str, enum.Enum):
    LEFT = "left"
    TOP_LEFT = "top-left"
    TOP = "top"
    TOP_RIGHT = "top-right"
    RIGHT = "right"
    BOTTOM_RIGHT = "bottom-right"
    BOTTOM = "bottom"
    BOTTOM_LEFT = "bottom-left"
    CENTER = "center"


DivTooltip.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


class DivLayoutProvider(BaseDiv):

    def __init__(
        self, *,
        height_variable_name: typing.Optional[typing.Union[Expr, str]] = None,
        width_variable_name: typing.Optional[typing.Union[Expr, str]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            height_variable_name=height_variable_name,
            width_variable_name=width_variable_name,
            **kwargs,
        )

    height_variable_name: typing.Optional[typing.Union[Expr, str]] = Field(
        description="Name of the variable that stores the element’s height.",
    )
    width_variable_name: typing.Optional[typing.Union[Expr, str]] = Field(
        description="Name of the variable that stores the element’s width.",
    )


DivLayoutProvider.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_size_unit


# Fixed coordinates of the rotation axis.
class DivPivotFixed(BaseDiv):

    def __init__(
        self, *,
        type: str = "pivot-fixed",
        unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = None,
        value: typing.Optional[typing.Union[Expr, int]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            unit=unit,
            value=value,
            **kwargs,
        )

    type: str = Field(default="pivot-fixed")
    unit: typing.Optional[typing.Union[Expr, div_size_unit.DivSizeUnit]] = Field(
        description=(
            "Measurement unit. To learn more about units of size "
            "measurement, see [Layoutinside the card](../../layout)."
        ),
    )
    value: typing.Optional[typing.Union[Expr, int]] = Field(
        description="Coordinate value.",
    )


DivPivotFixed.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Relative radius of the gradient transition.
class DivRadialGradientRelativeRadius(BaseDiv):

    def __init__(
        self, *,
        type: str = "relative",
        value: typing.Optional[typing.Union[Expr, DivRadialGradientRelativeRadiusValue]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            value=value,
            **kwargs,
        )

    type: str = Field(default="relative")
    value: typing.Union[Expr, DivRadialGradientRelativeRadiusValue] = Field(
        description="Type of the relative radius of the gradient transition.",
    )


class DivRadialGradientRelativeRadiusValue(str, enum.Enum):
    NEAREST_CORNER = "nearest_corner"
    FARTHEST_CORNER = "farthest_corner"
    NEAREST_SIDE = "nearest_side"
    FARTHEST_SIDE = "farthest_side"


DivRadialGradientRelativeRadius.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field

from . import div_fixed_size


# A mask to hide text (spoiler). Looks like randomly distributed particles, same as
# in Telegram.
class DivTextRangeMaskParticles(BaseDiv):

    def __init__(
        self, *,
        type: str = "particles",
        color: typing.Optional[typing.Union[Expr, str]] = None,
        density: typing.Optional[typing.Union[Expr, float]] = None,
        is_animated: typing.Optional[typing.Union[Expr, bool]] = None,
        is_enabled: typing.Optional[typing.Union[Expr, bool]] = None,
        particle_size: typing.Optional[div_fixed_size.DivFixedSize] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            color=color,
            density=density,
            is_animated=is_animated,
            is_enabled=is_enabled,
            particle_size=particle_size,
            **kwargs,
        )

    type: str = Field(default="particles")
    color: typing.Union[Expr, str] = Field(
        format="color", 
        description="The color of particles on the mask.",
    )
    density: typing.Optional[typing.Union[Expr, float]] = Field(
        description=(
            "The density of particles on the mask. Interpreted as the "
            "probability of aparticle to appear in a given point on the "
            "mask."
        ),
    )
    is_animated: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Enables animation for particles on the mask. The animation "
            "looks like a smoothmovement of particles across the mask, "
            "same as in Telegram."
        ),
    )
    is_enabled: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Controls the mask state. If set to `true`, the mask will "
            "hide the specified partof text. Otherwise, the text will be "
            "shown."
        ),
    )
    particle_size: typing.Optional[div_fixed_size.DivFixedSize] = Field(
        description="The size of a single particle on the mask.",
    )


DivTextRangeMaskParticles.update_forward_refs()



# Generated code. Do not modify.
# flake8: noqa: F401, F405, F811

from __future__ import annotations

import enum
import typing

from pydivkit.core import BaseDiv, Expr, Field


# Shows the tooltip.
class DivActionShowTooltip(BaseDiv):

    def __init__(
        self, *,
        type: str = "show_tooltip",
        id: typing.Optional[typing.Union[Expr, str]] = None,
        multiple: typing.Optional[typing.Union[Expr, bool]] = None,
        **kwargs: typing.Any,
    ):
        super().__init__(
            type=type,
            id=id,
            multiple=multiple,
            **kwargs,
        )

    type: str = Field(default="show_tooltip")
    id: typing.Union[Expr, str] = Field(
        description="Tooltip ID.",
    )
    multiple: typing.Optional[typing.Union[Expr, bool]] = Field(
        description=(
            "Sets whether the tooltip can be shown again after it’s "
            "closed."
        ),
    )


DivActionShowTooltip.update_forward_refs()
